Struct amazon_sp_aplus_content::models::image_crop_specification::ImageCropSpecification
source · [−]pub struct ImageCropSpecification {
pub size: Box<ImageDimensions>,
pub offset: Option<Box<ImageOffsets>>,
}Expand description
ImageCropSpecification : The instructions for optionally cropping an image. If no cropping is desired, set the dimensions to the original image size. If the image is cropped and no offset values are provided, then the coordinates of the top left corner of the cropped image, relative to the original image, are defaulted to (0,0).
Fields
size: Box<ImageDimensions>offset: Option<Box<ImageOffsets>>Implementations
sourceimpl ImageCropSpecification
impl ImageCropSpecification
sourcepub fn new(size: ImageDimensions) -> ImageCropSpecification
pub fn new(size: ImageDimensions) -> ImageCropSpecification
The instructions for optionally cropping an image. If no cropping is desired, set the dimensions to the original image size. If the image is cropped and no offset values are provided, then the coordinates of the top left corner of the cropped image, relative to the original image, are defaulted to (0,0).